StorageErrorCode

Enum StorageErrorCode 

pub enum StorageErrorCode {
Show 117 variants AccountAlreadyExists, AccountBeingCreated, AccountIsDisabled, AppendPositionConditionNotMet, AuthenticationFailed, AuthorizationFailure, AuthorizationPermissionMismatch, AuthorizationProtocolMismatch, AuthorizationResourceTypeMismatch, AuthorizationServiceMismatch, AuthorizationSourceIPMismatch, BlobAccessTierNotSupportedForAccountType, BlobAlreadyExists, BlobArchived, BlobBeingRehydrated, BlobImmutableDueToPolicy, BlobNotArchived, BlobNotFound, BlobOverwritten, BlobTierInadequateForContentLength, BlobUsesCustomerSpecifiedEncryption, BlockCountExceedsLimit, BlockListTooLong, CannotChangeToLowerTier, CannotVerifyCopySource, ConditionHeadersNotSupported, ConditionNotMet, ContainerAlreadyExists, ContainerBeingDeleted, ContainerDisabled, ContainerNotFound, ContentLengthLargerThanTierLimit, CopyAcrossAccountsNotSupported, CopyIdMismatch, EmptyMetadataKey, FeatureVersionMismatch, IncrementalCopyBlobMismatch, IncrementalCopyOfEarlierSnapshotNotAllowed, IncrementalCopyOfEarlierVersionSnapshotNotAllowed, IncrementalCopySourceMustBeSnapshot, InfiniteLeaseDurationRequired, InsufficientAccountPermissions, InternalError, InvalidAuthenticationInfo, InvalidBlobOrBlock, InvalidBlobTier, InvalidBlobType, InvalidBlockId, InvalidBlockList, InvalidHeaderValue, InvalidHttpVerb, InvalidInput, InvalidMd5, InvalidMetadata, InvalidOperation, InvalidPageRange, InvalidQueryParameterValue, InvalidRange, InvalidRequestUrl, InvalidResourceName, InvalidSourceBlobType, InvalidSourceBlobUrl, InvalidUri, InvalidVersionForPageBlobOperation, InvalidXmlDocument, InvalidXmlNodeValue, LeaseAlreadyBroken, LeaseAlreadyPresent, LeaseIdMismatchWithBlobOperation, LeaseIdMismatchWithContainerOperation, LeaseIdMismatchWithLeaseOperation, LeaseIdMissing, LeaseIsBreakingAndCannotBeAcquired, LeaseIsBreakingAndCannotBeChanged, LeaseIsBrokenAndCannotBeRenewed, LeaseLost, LeaseNotPresentWithBlobOperation, LeaseNotPresentWithContainerOperation, LeaseNotPresentWithLeaseOperation, MaxBlobSizeConditionNotMet, Md5Mismatch, MetadataTooLarge, MissingContentLengthHeader, MissingRequiredHeader, MissingRequiredQueryParameter, MissingRequiredXmlNode, MultipleConditionHeadersNotSupported, NoAuthenticationInformation, NoPendingCopyOperation, OperationNotAllowedOnIncrementalCopyBlob, OperationTimedOut, OutOfRangeInput, OutOfRangeQueryParameterValue, PendingCopyOperation, PreviousSnapshotCannotBeNewer, PreviousSnapshotNotFound, PreviousSnapshotOperationNotSupported, RequestBodyTooLarge, RequestUrlFailedToParse, ResourceAlreadyExists, ResourceNotFound, ResourceTypeMismatch, SequenceNumberConditionNotMet, SequenceNumberIncrementTooLarge, ServerBusy, SnapshotCountExceeded, SnapshotOperationRateExceeded, SnapshotsPresent, SourceConditionNotMet, SystemInUse, TargetConditionNotMet, UnauthorizedBlobOverwrite, UnsupportedHeader, UnsupportedHttpVerb, UnsupportedQueryParameter, UnsupportedXmlNode, UnknownValue(String),
}
Error codes returned by the Azure Blob Storage service.

Variants



AccountAlreadyExists

Account already exists.



AccountBeingCreated

Account is being created.



AccountIsDisabled

Account is disabled.



AppendPositionConditionNotMet

Append position condition not met.



AuthenticationFailed

Authentication failed.



AuthorizationFailure

Authorization failure.



AuthorizationPermissionMismatch

Authorization permission mismatch.



AuthorizationProtocolMismatch

Authorization protocol mismatch.



AuthorizationResourceTypeMismatch

Authorization resource type mismatch.



AuthorizationServiceMismatch

Authorization service mismatch.



AuthorizationSourceIPMismatch

Authorization source IP mismatch.



BlobAccessTierNotSupportedForAccountType

Blob access tier not supported for account type.



BlobAlreadyExists

Blob already exists.



BlobArchived

Blob archived.



BlobBeingRehydrated

Blob being rehydrated.



BlobImmutableDueToPolicy

Blob is immutable due to policy.



BlobNotArchived

Blob not archived.



BlobNotFound

Blob not found.



BlobOverwritten

Blob overwritten.



BlobTierInadequateForContentLength

Blob tier inadequate for content length.



BlobUsesCustomerSpecifiedEncryption

Blob uses customer specified encryption.



BlockCountExceedsLimit

Block count exceeds limit.



BlockListTooLong

Block list too long.



CannotChangeToLowerTier

Cannot change to lower tier.



CannotVerifyCopySource

Cannot verify copy source.



ConditionHeadersNotSupported

Condition headers not supported.



ConditionNotMet

Condition not met.



ContainerAlreadyExists

Container already exists.



ContainerBeingDeleted

Container being deleted.



ContainerDisabled

Container disabled.



ContainerNotFound

Container not found.



ContentLengthLargerThanTierLimit

Content length larger than tier limit.



CopyAcrossAccountsNotSupported

Copy across accounts not supported.



CopyIdMismatch

Copy ID mismatch.



EmptyMetadataKey

Empty metadata key.



FeatureVersionMismatch

Feature version mismatch.



IncrementalCopyBlobMismatch

Incremental copy blob mismatch.



IncrementalCopyOfEarlierSnapshotNotAllowed

Incremental copy of an earlier snapshot is not allowed.



IncrementalCopyOfEarlierVersionSnapshotNotAllowed

Incremental copy of an earlier version snapshot is not allowed.



IncrementalCopySourceMustBeSnapshot

Incremental copy source must be snapshot.



InfiniteLeaseDurationRequired

Infinite lease duration required.



InsufficientAccountPermissions

Insufficient account permissions.



InternalError

Internal error.



InvalidAuthenticationInfo

Invalid authentication information.



InvalidBlobOrBlock

Invalid blob or block.



InvalidBlobTier

Invalid blob tier.



InvalidBlobType

Invalid blob type.



InvalidBlockId

Invalid block ID.



InvalidBlockList

Invalid block list.



InvalidHeaderValue

Invalid header value.



InvalidHttpVerb

Invalid HTTP verb.



InvalidInput

Invalid input.



InvalidMd5

Invalid MD5.



InvalidMetadata

Invalid metadata.



InvalidOperation

Invalid operation.



InvalidPageRange

Invalid page range.



InvalidQueryParameterValue

Invalid query parameter value.



InvalidRange

Invalid range.



InvalidRequestUrl

Invalid request URL.



InvalidResourceName

Invalid resource name.



InvalidSourceBlobType

Invalid source blob type.



InvalidSourceBlobUrl

Invalid source blob URL.



InvalidUri

Invalid URI.



InvalidVersionForPageBlobOperation

Invalid version for page blob operation.



InvalidXmlDocument

Invalid XML document.



InvalidXmlNodeValue

Invalid XML node value.



LeaseAlreadyBroken

Lease already broken.



LeaseAlreadyPresent

Lease already present.



LeaseIdMismatchWithBlobOperation

Lease ID mismatch with blob operation.



LeaseIdMismatchWithContainerOperation

Lease ID mismatch with container operation.



LeaseIdMismatchWithLeaseOperation

Lease ID mismatch with lease operation.



LeaseIdMissing

Lease ID missing.



LeaseIsBreakingAndCannotBeAcquired

Lease is breaking and cannot be acquired.



LeaseIsBreakingAndCannotBeChanged

Lease is breaking and cannot be changed.



LeaseIsBrokenAndCannotBeRenewed

Lease is broken and cannot be renewed.



LeaseLost

Lease lost.



LeaseNotPresentWithBlobOperation

Lease not present with blob operation.



LeaseNotPresentWithContainerOperation

Lease not present with container operation.



LeaseNotPresentWithLeaseOperation

Lease not present with lease operation.



MaxBlobSizeConditionNotMet

Maximum blob size condition not met.



Md5Mismatch

MD5 mismatch.



MetadataTooLarge

Metadata too large.



MissingContentLengthHeader

Missing content length header.



MissingRequiredHeader

Missing required header.



MissingRequiredQueryParameter

Missing required query parameter.



MissingRequiredXmlNode

Missing required XML node.



MultipleConditionHeadersNotSupported

Multiple condition headers not supported.



NoAuthenticationInformation

No authentication information.



NoPendingCopyOperation

No pending copy operation.



OperationNotAllowedOnIncrementalCopyBlob

Operation not allowed on incremental copy blob.



OperationTimedOut

Operation timed out.



OutOfRangeInput

Out of range input.



OutOfRangeQueryParameterValue

Out of range query parameter value.



PendingCopyOperation

Pending copy operation.



PreviousSnapshotCannotBeNewer

Previous snapshot cannot be newer.



PreviousSnapshotNotFound

Previous snapshot not found.



PreviousSnapshotOperationNotSupported

Previous snapshot operation not supported.



RequestBodyTooLarge

Request body too large.



RequestUrlFailedToParse

Request URL failed to parse.



ResourceAlreadyExists

Resource already exists.



ResourceNotFound

Resource not found.



ResourceTypeMismatch

Resource type mismatch.



SequenceNumberConditionNotMet

Sequence number condition not met.



SequenceNumberIncrementTooLarge

Sequence number increment too large.



ServerBusy

Server busy.



SnapshotCountExceeded

Snapshot count exceeded.



SnapshotOperationRateExceeded

Snapshot operation rate exceeded.



SnapshotsPresent

Snapshots present.



SourceConditionNotMet

Source condition not met.



SystemInUse

System in use.



TargetConditionNotMet

Target condition not met.



UnauthorizedBlobOverwrite

Unauthorized blob overwrite.



UnsupportedHeader

Unsupported header.



UnsupportedHttpVerb

Unsupported HTTP verb.



UnsupportedQueryParameter

Unsupported query parameter.



UnsupportedXmlNode

Unsupported XML node.



UnknownValue(String)

Any other value not defined in StorageErrorCode.