pub struct AppendBlobClientAppendBlockOptions<'a> {Show 16 fields
pub append_position: Option<i64>,
pub encryption_algorithm: Option<EncryptionAlgorithmType>,
pub encryption_key: Option<String>,
pub encryption_key_sha256: Option<String>,
pub encryption_scope: Option<String>,
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub lease_id: Option<String>,
pub max_size: Option<i64>,
pub method_options: ClientMethodOptions<'a>,
pub timeout: Option<i32>,
pub transactional_content_crc64: Option<Vec<u8>>,
pub transactional_content_md5: Option<Vec<u8>>,
}Expand description
Options to be passed to AppendBlobClient::append_block()
Fields
append_position: Option<i64>A byte offset where the operation will only succeed if the append position is equal. If not, the request will fail with AppendPositionConditionNotMet.
encryption_algorithm: Option<EncryptionAlgorithmType>The algorithm used to produce the encryption key hash. Must be provided if the encryption key is provided.
encryption_key: Option<String>Specifies the encryption key to use to encrypt the data provided in the request.
encryption_key_sha256: Option<String>The SHA-256 hash of the provided encryption key. Must be provided if the encryption key is provided.
encryption_scope: Option<String>Specifies the encryption scope used to encrypt the data.
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
max_size: Option<i64>The max length of the blob. If the operation would cause the blob to exceed that limit or if the blob size is already greater than the value specified, the request will fail with MaxBlobSizeConditionNotMet.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.
transactional_content_crc64: Option<Vec<u8>>Specifies the transactional CRC64 hash for the body.
transactional_content_md5: Option<Vec<u8>>Specifies the transactional MD5 hash for the body.