pub struct AppendBlobClientSealOptions<'a> {
pub append_position: Option<i64>,
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub lease_id: Option<String>,
pub method_options: ClientMethodOptions<'a>,
pub timeout: Option<i32>,
}Expand description
Options to be passed to AppendBlobClient::seal()
Fields
append_position: Option<i64>A byte offset where the operation will only succeed if the append position is equal. If not, the request will fail with AppendPositionConditionNotMet.
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.