pub struct BlobClientDeleteOptions<'a> {Show 14 fields
pub access_tier_if_modified_since: Option<OffsetDateTime>,
pub access_tier_if_unmodified_since: Option<OffsetDateTime>,
pub blob_delete_type: Option<BlobDeleteType>,
pub delete_snapshots: Option<DeleteSnapshotsOptionType>,
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub lease_id: Option<String>,
pub method_options: ClientMethodOptions<'a>,
pub snapshot: Option<String>,
pub timeout: Option<i32>,
pub version_id: Option<String>,
}Expand description
Options to be passed to BlobClient::delete()
Fields
access_tier_if_modified_since: Option<OffsetDateTime>Specify this header value to operate only on a blob if the access-tier has been modified since the specified date-time.
access_tier_if_unmodified_since: Option<OffsetDateTime>Specify this header value to operate only on a blob if the access-tier has not been modified since the specified date-time.
blob_delete_type: Option<BlobDeleteType>The delete type.
delete_snapshots: Option<DeleteSnapshotsOptionType>Required if the blob has associated snapshots. Specifies the delete behavior.
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
snapshot: Option<String>Specifies the snapshot of the blob.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.
version_id: Option<String>Specifies the version ID of the blob.