pub struct BlobClientDownloadIntoResult {
pub len: usize,
pub properties: BlobDownloadProperties,
pub headers: Headers,
}Expand description
Result of a BlobClient::download_into() operation.
Fields
len: usizeThe length of data written to the provided buffer.
properties: BlobDownloadPropertiesBlob properties parsed from the initial response.
headers: HeadersAll headers from the initial response.
Use this to access headers that are not surfaced as named fields, such as
x-ms-request-id, x-ms-client-request-id, and more.