pub struct BlobClientDownloadResult {
pub body: AsyncResponseBody,
pub properties: BlobDownloadProperties,
pub headers: Headers,
}Expand description
Result of a BlobClient::download() operation.
The full blob content over the requested range is streamed via body.
All other fields: properties, and headers, are parsed
from the initial response.
Fields
body: AsyncResponseBodyThe blob content stream.
properties: BlobDownloadPropertiesBlob properties parsed from the initial response.
headers: HeadersAll headers from the initial response.
Use this to access headers that are not surfaced as named fields, such as
x-ms-request-id, x-ms-client-request-id, and more.