pub struct BlobClientReleaseLeaseOptions<'a> {
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub method_options: ClientMethodOptions<'a>,
pub timeout: Option<i32>,
}Expand description
Options to be passed to BlobClient::release_lease()
Fields
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.