pub struct BlobClientSetPropertiesOptions<'a> {Show 14 fields
pub blob_cache_control: Option<String>,
pub blob_content_disposition: Option<String>,
pub blob_content_encoding: Option<String>,
pub blob_content_language: Option<String>,
pub blob_content_md5: Option<Vec<u8>>,
pub blob_content_type: Option<String>,
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub lease_id: Option<String>,
pub method_options: ClientMethodOptions<'a>,
pub timeout: Option<i32>,
}Expand description
Options to be passed to BlobClient::set_properties()
Fields
blob_cache_control: Option<String>Specifies the blob’s Cache-Control. If specified, this property is stored with the blob and returned with a read request.
blob_content_disposition: Option<String>Specifies the blob’s Content-Disposition. If specified, this property is stored with the blob and returned with a read request.
blob_content_encoding: Option<String>Specifies the blob’s Content-Encoding. If specified, this property is stored with the blob and returned with a read request.
blob_content_language: Option<String>Specifies the blob’s Content-Language. If specified, this property is stored with the blob and returned with a read request.
blob_content_md5: Option<Vec<u8>>The MD5 hash of the blob content that is stored as a property on the blob. Note: This hash is not validated.
blob_content_type: Option<String>Specifies the blob’s Content-Type. If specified, this property is stored with the blob and returned with a read request.
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.