pub struct BlobClientSetTierOptions<'a> {
pub if_tags: Option<String>,
pub lease_id: Option<String>,
pub method_options: ClientMethodOptions<'a>,
pub rehydrate_priority: Option<RehydratePriority>,
pub snapshot: Option<String>,
pub timeout: Option<i32>,
pub version_id: Option<String>,
}Expand description
Options to be passed to BlobClient::set_tier()
Fields
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
rehydrate_priority: Option<RehydratePriority>The priority of the rehydration operation.
snapshot: Option<String>Specifies the snapshot of the blob.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.
version_id: Option<String>Specifies the version ID of the blob.