pub struct BlobClientStartCopyFromUrlOptions<'a> {Show 21 fields
pub blob_tags_string: Option<String>,
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub immutability_policy_expiry: Option<OffsetDateTime>,
pub immutability_policy_mode: Option<ImmutabilityPolicyMode>,
pub lease_id: Option<String>,
pub legal_hold: Option<bool>,
pub metadata: Option<HashMap<String, String>>,
pub method_options: ClientMethodOptions<'a>,
pub rehydrate_priority: Option<RehydratePriority>,
pub seal_blob: Option<bool>,
pub source_if_match: Option<Etag>,
pub source_if_modified_since: Option<OffsetDateTime>,
pub source_if_none_match: Option<Etag>,
pub source_if_tags: Option<String>,
pub source_if_unmodified_since: Option<OffsetDateTime>,
pub tier: Option<AccessTier>,
pub timeout: Option<i32>,
}Expand description
Options to be passed to BlobClient::start_copy_from_url()
Fields
The blob tags.
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
immutability_policy_expiry: Option<OffsetDateTime>The date-time that indicates the time at which the blob immutability policy will expire.
immutability_policy_mode: Option<ImmutabilityPolicyMode>Indicates the immutability policy mode of the blob.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
legal_hold: Option<bool>Indicates whether the blob has a legal hold.
metadata: Option<HashMap<String, String>>The metadata headers.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
rehydrate_priority: Option<RehydratePriority>The priority of the rehydration operation.
seal_blob: Option<bool>Overrides the sealed state of the destination blob.
source_if_match: Option<Etag>Specify this value to operate only on a source blob with a matching Etag value.
source_if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a source blob if it has been modified since the specified date-time.
source_if_none_match: Option<Etag>Specify this value to operate only on a source blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a source blob with matching tags.
source_if_unmodified_since: Option<OffsetDateTime>Specify this header value to operate only on a blob if it has not been modified since the specified date-time.
tier: Option<AccessTier>The tier to be set on the blob.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.