pub struct BlobClientUploadResult {
pub etag: Option<Etag>,
pub last_modified: Option<OffsetDateTime>,
pub content_md5: Option<Vec<u8>>,
pub content_crc64: Option<Vec<u8>>,
pub encryption_key_sha256: Option<String>,
pub encryption_scope: Option<String>,
pub is_server_encrypted: Option<bool>,
pub version_id: Option<String>,
pub raw_response: RawResponse,
}Expand description
Result of a BlockBlobClient::upload() or BlobClient::upload() operation.
Fields
etag: Option<Etag>The blob’s ETag.
last_modified: Option<OffsetDateTime>The date/time the blob was last modified.
content_md5: Option<Vec<u8>>The MD5 hash of the blob content, if present.
content_crc64: Option<Vec<u8>>The CRC64 hash of the blob content, if present.
encryption_key_sha256: Option<String>The SHA-256 hash of the encryption key used to encrypt the blob, if any.
encryption_scope: Option<String>The encryption scope used to encrypt the blob, if any.
is_server_encrypted: Option<bool>Whether the blob was successfully encrypted server-side.
version_id: Option<String>The version ID of the blob, if versioning is enabled on the storage account.
raw_response: RawResponseThe raw HTTP response.