pub struct BlobContainerClientListBlobsOptions<'a> {
pub include: Option<Vec<ListBlobsIncludeItem>>,
pub marker: Option<String>,
pub maxresults: Option<i32>,
pub method_options: PagerOptions<'a>,
pub prefix: Option<String>,
pub start_from: Option<String>,
pub timeout: Option<i32>,
}Expand description
Options to be passed to BlobContainerClient::list_blobs()
Fields
include: Option<Vec<ListBlobsIncludeItem>>Specify to include additional, optional information.
marker: Option<String>An opaque string value that identifies the portion of the result set to return with this operation.
maxresults: Option<i32>Specifies the maximum number of resources to return. If the request does not specify maxresults, or specifies a value greater than 5000, the server will return up to 5000 items.
method_options: PagerOptions<'a>Allows customization of the method call.
prefix: Option<String>Filters the results to return only resources whose name begins with the specified prefix.
start_from: Option<String>Specifies the relative path to list paths from. For non-recursive list, only one entity level is supported; for recursive list, multiple entity levels are supported. (Inclusive)
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.
Implementations
Sourceimpl BlobContainerClientListBlobsOptions<'_>
impl BlobContainerClientListBlobsOptions<'_>
Sourcepub fn into_owned(self) -> BlobContainerClientListBlobsOptions<'static>
pub fn into_owned(self) -> BlobContainerClientListBlobsOptions<'static>
Transforms this BlobContainerClientListBlobsOptions into a new BlobContainerClientListBlobsOptions that owns the underlying data, cloning it if necessary.