BlockBlobClientCommitBlockListOptions

Struct BlockBlobClientCommitBlockListOptions 

pub struct BlockBlobClientCommitBlockListOptions<'a> {
Show 26 fields pub blob_cache_control: Option<String>, pub blob_content_disposition: Option<String>, pub blob_content_encoding: Option<String>, pub blob_content_language: Option<String>, pub blob_content_md5: Option<Vec<u8>>, pub blob_content_type: Option<String>, pub blob_tags_string: Option<String>, pub encryption_algorithm: Option<EncryptionAlgorithmType>, pub encryption_key: Option<String>, pub encryption_key_sha256: Option<String>, pub encryption_scope: Option<String>, pub if_match: Option<Etag>, pub if_modified_since: Option<OffsetDateTime>, pub if_none_match: Option<Etag>, pub if_tags: Option<String>, pub if_unmodified_since: Option<OffsetDateTime>, pub immutability_policy_expiry: Option<OffsetDateTime>, pub immutability_policy_mode: Option<ImmutabilityPolicyMode>, pub lease_id: Option<String>, pub legal_hold: Option<bool>, pub metadata: Option<HashMap<String, String>>, pub method_options: ClientMethodOptions<'a>, pub tier: Option<AccessTier>, pub timeout: Option<i32>, pub transactional_content_crc64: Option<Vec<u8>>, pub transactional_content_md5: Option<Vec<u8>>,
}
Options to be passed to BlockBlobClient::commit_block_list()

Fields

blob_cache_control: Option<String>

Specifies the blob’s Cache-Control. If specified, this property is stored with the blob and returned with a read request.

blob_content_disposition: Option<String>

Specifies the blob’s Content-Disposition. If specified, this property is stored with the blob and returned with a read request.

blob_content_encoding: Option<String>

Specifies the blob’s Content-Encoding. If specified, this property is stored with the blob and returned with a read request.

blob_content_language: Option<String>

Specifies the blob’s Content-Language. If specified, this property is stored with the blob and returned with a read request.

blob_content_md5: Option<Vec<u8>>

The MD5 hash of the blob content that is stored as a property on the blob. Note: This hash is not validated.

blob_content_type: Option<String>

Specifies the blob’s Content-Type. If specified, this property is stored with the blob and returned with a read request.

blob_tags_string: Option<String>

The blob tags.

encryption_algorithm: Option<EncryptionAlgorithmType>

The algorithm used to produce the encryption key hash. Must be provided if the encryption key is provided.

encryption_key: Option<String>

Specifies the encryption key to use to encrypt the data provided in the request.

encryption_key_sha256: Option<String>

The SHA-256 hash of the provided encryption key. Must be provided if the encryption key is provided.

encryption_scope: Option<String>

Specifies the encryption scope used to encrypt the data.

if_match: Option<Etag>

Specify this value to operate only on a blob with a matching Etag value.

if_modified_since: Option<OffsetDateTime>

Specify this value to operate only on a blob if it has been modified since the specified date-time.

if_none_match: Option<Etag>

Specify this value to operate only on a blob with a non-matching Etag value.

if_tags: Option<String>

Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.

if_unmodified_since: Option<OffsetDateTime>

Specify this value to operate only on a blob if it has not been modified since the specified date-time.

immutability_policy_expiry: Option<OffsetDateTime>

The date-time that indicates the time at which the blob immutability policy will expire.

immutability_policy_mode: Option<ImmutabilityPolicyMode>

Indicates the immutability policy mode of the blob.

lease_id: Option<String>

If specified, the operation only succeeds if the resource’s lease is active and matches this ID.

legal_hold: Option<bool>

Indicates whether the blob has a legal hold.

metadata: Option<HashMap<String, String>>

The metadata headers.

method_options: ClientMethodOptions<'a>

Allows customization of the method call.

tier: Option<AccessTier>

The tier to be set on the blob.

timeout: Option<i32>

The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.

transactional_content_crc64: Option<Vec<u8>>

Specifies the transactional CRC64 hash for the body.

transactional_content_md5: Option<Vec<u8>>

Specifies the transactional MD5 hash for the body.

Implementations