pub struct BlockBlobClientStageBlockFromUrlOptions<'a> {Show 19 fields
pub copy_source_authorization: Option<String>,
pub encryption_algorithm: Option<EncryptionAlgorithmType>,
pub encryption_key: Option<String>,
pub encryption_key_sha256: Option<String>,
pub encryption_scope: Option<String>,
pub file_request_intent: Option<FileShareTokenIntent>,
pub lease_id: Option<String>,
pub method_options: ClientMethodOptions<'a>,
pub source_content_crc64: Option<Vec<u8>>,
pub source_content_md5: Option<Vec<u8>>,
pub source_encryption_algorithm: Option<EncryptionAlgorithmType>,
pub source_encryption_key: Option<String>,
pub source_encryption_key_sha256: Option<String>,
pub source_if_match: Option<Etag>,
pub source_if_modified_since: Option<OffsetDateTime>,
pub source_if_none_match: Option<Etag>,
pub source_if_unmodified_since: Option<OffsetDateTime>,
pub source_range: Option<HttpRange>,
pub timeout: Option<i32>,
}Expand description
Options to be passed to BlockBlobClient::stage_block_from_url()
Fields
Only the Bearer authorization scheme is supported, and the value must be a valid OAuth access token for the copy source.
encryption_algorithm: Option<EncryptionAlgorithmType>The algorithm used to produce the encryption key hash. Must be provided if the encryption key is provided.
encryption_key: Option<String>Specifies the encryption key to use to encrypt the data provided in the request.
encryption_key_sha256: Option<String>The SHA-256 hash of the provided encryption key. Must be provided if the encryption key is provided.
encryption_scope: Option<String>Specifies the encryption scope used to encrypt the data.
file_request_intent: Option<FileShareTokenIntent>Specifies the file request token intent.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
source_content_crc64: Option<Vec<u8>>Specifies the CRC64 calculated for the range of bytes that must be read from the source.
source_content_md5: Option<Vec<u8>>Specifies the MD5 hash calculated for the range of bytes that must be read from the copy source.
source_encryption_algorithm: Option<EncryptionAlgorithmType>The algorithm used to produce the source encryption key hash. Must be provided if the source encryption key is provided.
source_encryption_key: Option<String>Specifies the encryption key to use to decrypt the source data provided in the request.
source_encryption_key_sha256: Option<String>The SHA-256 hash of the provided source encryption key. Must be provided if the source encryption key is provided.
source_if_match: Option<Etag>Specify this value to operate only on a source blob with a matching Etag value.
source_if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a source blob if it has been modified since the specified date-time.
source_if_none_match: Option<Etag>Specify this value to operate only on a source blob with a non-matching Etag value.
source_if_unmodified_since: Option<OffsetDateTime>Specify this header value to operate only on a blob if it has not been modified since the specified date-time.
source_range: Option<HttpRange>Specifies the bytes of the source.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.