pub struct BlockBlobClientStageBlockOptions<'a> {
pub encryption_algorithm: Option<EncryptionAlgorithmType>,
pub encryption_key: Option<String>,
pub encryption_key_sha256: Option<String>,
pub encryption_scope: Option<String>,
pub lease_id: Option<String>,
pub method_options: ClientMethodOptions<'a>,
pub timeout: Option<i32>,
pub transactional_content_crc64: Option<Vec<u8>>,
pub transactional_content_md5: Option<Vec<u8>>,
}Expand description
Options to be passed to BlockBlobClient::stage_block()
Fields
encryption_algorithm: Option<EncryptionAlgorithmType>The algorithm used to produce the encryption key hash. Must be provided if the encryption key is provided.
encryption_key: Option<String>Specifies the encryption key to use to encrypt the data provided in the request.
encryption_key_sha256: Option<String>The SHA-256 hash of the provided encryption key. Must be provided if the encryption key is provided.
encryption_scope: Option<String>Specifies the encryption scope used to encrypt the data.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.
transactional_content_crc64: Option<Vec<u8>>Specifies the transactional CRC64 hash for the body.
transactional_content_md5: Option<Vec<u8>>Specifies the transactional MD5 hash for the body.