pub struct BlockBlobClientUploadBlobFromUrlOptions<'a> {Show 35 fields
pub blob_cache_control: Option<String>,
pub blob_content_disposition: Option<String>,
pub blob_content_encoding: Option<String>,
pub blob_content_language: Option<String>,
pub blob_content_md5: Option<Vec<u8>>,
pub blob_content_type: Option<String>,
pub blob_tags_string: Option<String>,
pub copy_source_authorization: Option<String>,
pub copy_source_blob_properties: Option<bool>,
pub copy_source_tags: Option<BlobCopySourceTags>,
pub encryption_algorithm: Option<EncryptionAlgorithmType>,
pub encryption_key: Option<String>,
pub encryption_key_sha256: Option<String>,
pub encryption_scope: Option<String>,
pub file_request_intent: Option<FileShareTokenIntent>,
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub lease_id: Option<String>,
pub metadata: Option<HashMap<String, String>>,
pub method_options: ClientMethodOptions<'a>,
pub source_content_md5: Option<Vec<u8>>,
pub source_encryption_algorithm: Option<EncryptionAlgorithmType>,
pub source_encryption_key: Option<String>,
pub source_encryption_key_sha256: Option<String>,
pub source_if_match: Option<Etag>,
pub source_if_modified_since: Option<OffsetDateTime>,
pub source_if_none_match: Option<Etag>,
pub source_if_tags: Option<String>,
pub source_if_unmodified_since: Option<OffsetDateTime>,
pub tier: Option<AccessTier>,
pub timeout: Option<i32>,
pub transactional_content_md5: Option<Vec<u8>>,
}Expand description
Options to be passed to BlockBlobClient::upload_blob_from_url()
Fields
blob_cache_control: Option<String>Specifies the blob’s Cache-Control. If specified, this property is stored with the blob and returned with a read request.
blob_content_disposition: Option<String>Specifies the blob’s Content-Disposition. If specified, this property is stored with the blob and returned with a read request.
blob_content_encoding: Option<String>Specifies the blob’s Content-Encoding. If specified, this property is stored with the blob and returned with a read request.
blob_content_language: Option<String>Specifies the blob’s Content-Language. If specified, this property is stored with the blob and returned with a read request.
blob_content_md5: Option<Vec<u8>>The MD5 hash of the blob content that is stored as a property on the blob. Note: This hash is not validated.
blob_content_type: Option<String>Specifies the blob’s Content-Type. If specified, this property is stored with the blob and returned with a read request.
The blob tags.
Only the Bearer authorization scheme is supported, and the value must be a valid OAuth access token for the copy source.
copy_source_blob_properties: Option<bool>Indicates if properties from the source blob should be copied. Default is true.
Indicates if source tags should be copied or replaced with the tags specified. Default is ‘Replace’.
encryption_algorithm: Option<EncryptionAlgorithmType>The algorithm used to produce the encryption key hash. Must be provided if the encryption key is provided.
encryption_key: Option<String>Specifies the encryption key to use to encrypt the data provided in the request.
encryption_key_sha256: Option<String>The SHA-256 hash of the provided encryption key. Must be provided if the encryption key is provided.
encryption_scope: Option<String>Specifies the encryption scope used to encrypt the data.
file_request_intent: Option<FileShareTokenIntent>Specifies the file request token intent.
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
metadata: Option<HashMap<String, String>>The metadata headers.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
source_content_md5: Option<Vec<u8>>Specifies the MD5 hash calculated for the range of bytes that must be read from the copy source.
source_encryption_algorithm: Option<EncryptionAlgorithmType>The algorithm used to produce the source encryption key hash. Must be provided if the source encryption key is provided.
source_encryption_key: Option<String>Specifies the encryption key to use to decrypt the source data provided in the request.
source_encryption_key_sha256: Option<String>The SHA-256 hash of the provided source encryption key. Must be provided if the source encryption key is provided.
source_if_match: Option<Etag>Specify this value to operate only on a source blob with a matching Etag value.
source_if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a source blob if it has been modified since the specified date-time.
source_if_none_match: Option<Etag>Specify this value to operate only on a source blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a source blob with matching tags.
source_if_unmodified_since: Option<OffsetDateTime>Specify this header value to operate only on a blob if it has not been modified since the specified date-time.
tier: Option<AccessTier>The tier to be set on the blob.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.
transactional_content_md5: Option<Vec<u8>>Specifies the transactional MD5 hash for the body.
Implementations
Sourceimpl BlockBlobClientUploadBlobFromUrlOptions<'_>
Augments the current options bag to only create if the Block blob does not already exist.
impl BlockBlobClientUploadBlobFromUrlOptions<'_>
Augments the current options bag to only create if the Block blob does not already exist.
Arguments
self- The options bag to be modified.
pub fn if_not_exists(self) -> Self