FilteredBlobResponse

Struct FilteredBlobResponse 

#[non_exhaustive]
pub struct FilteredBlobResponse { pub blob_items: Vec<FilterBlobItem>, pub next_marker: Option<String>, pub service_endpoint: Option<String>, pub where_prop: Option<String>, }
The result of the Find Blobs by Tags API.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
blob_items: Vec<FilterBlobItem>

The list of filtered blobs.

next_marker: Option<String>

An opaque string value that identifies the portion of the result set to be returned with the next operation. Use this value in the next request to continue the listing operation.

service_endpoint: Option<String>

The service endpoint.

where_prop: Option<String>

The filter expression for the blobs.