pub struct PageBlobClientClearPagesOptions<'a> {Show 15 fields
pub encryption_algorithm: Option<EncryptionAlgorithmType>,
pub encryption_key: Option<String>,
pub encryption_key_sha256: Option<String>,
pub encryption_scope: Option<String>,
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_sequence_number_equal_to: Option<i64>,
pub if_sequence_number_less_than: Option<i64>,
pub if_sequence_number_less_than_or_equal_to: Option<i64>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub lease_id: Option<String>,
pub method_options: ClientMethodOptions<'a>,
pub timeout: Option<i32>,
}Expand description
Options to be passed to PageBlobClient::clear_pages()
Fields
encryption_algorithm: Option<EncryptionAlgorithmType>The algorithm used to produce the encryption key hash. Must be provided if the encryption key is provided.
encryption_key: Option<String>Specifies the encryption key to use to encrypt the data provided in the request.
encryption_key_sha256: Option<String>The SHA-256 hash of the provided encryption key. Must be provided if the encryption key is provided.
encryption_scope: Option<String>Specifies the encryption scope used to encrypt the data.
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
if_sequence_number_equal_to: Option<i64>Specify this value to operate only on a blob if it has the specified sequence number.
if_sequence_number_less_than: Option<i64>Specify this value to operate only on a blob if it has a sequence number less than the specified.
if_sequence_number_less_than_or_equal_to: Option<i64>Specify this value to operate only on a blob if it has a sequence number less than or equal to the specified.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.