pub struct PageBlobClientListPageRangesOptions<'a> {
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub lease_id: Option<String>,
pub marker: Option<String>,
pub maxresults: Option<i32>,
pub method_options: PagerOptions<'a>,
pub range: Option<HttpRange>,
pub snapshot: Option<String>,
pub timeout: Option<i32>,
}Expand description
Options to be passed to PageBlobClient::list_page_ranges()
Fields
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
marker: Option<String>An opaque string value that identifies the portion of the result set to return with this operation.
maxresults: Option<i32>Specifies the maximum number of resources to return. If the request does not specify maxresults, or specifies a value greater than 5000, the server will return up to 5000 items.
method_options: PagerOptions<'a>Allows customization of the method call.
range: Option<HttpRange>Specifies the range of the blob to operate on.
snapshot: Option<String>Specifies the snapshot of the blob.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.
Implementations
Sourceimpl PageBlobClientListPageRangesOptions<'_>
impl PageBlobClientListPageRangesOptions<'_>
Sourcepub fn into_owned(self) -> PageBlobClientListPageRangesOptions<'static>
pub fn into_owned(self) -> PageBlobClientListPageRangesOptions<'static>
Transforms this PageBlobClientListPageRangesOptions into a new PageBlobClientListPageRangesOptions that owns the underlying data, cloning it if necessary.