BlobClientGetPropertiesResultHeaders

Trait BlobClientGetPropertiesResultHeaders 

pub trait BlobClientGetPropertiesResultHeaders: Sealed {
Show 44 methods // Required methods fn cache_control(&self) -> Result<Option<String>>; fn content_disposition(&self) -> Result<Option<String>>; fn content_encoding(&self) -> Result<Option<String>>; fn content_language(&self) -> Result<Option<String>>; fn content_length(&self) -> Result<Option<u64>>; fn content_md5(&self) -> Result<Option<Vec<u8>>>; fn content_type(&self) -> Result<Option<String>>; fn etag(&self) -> Result<Option<Etag>>; fn last_modified(&self) -> Result<Option<OffsetDateTime>>; fn access_tier(&self) -> Result<Option<String>>; fn access_tier_change_time(&self) -> Result<Option<OffsetDateTime>>; fn access_tier_inferred(&self) -> Result<Option<bool>>; fn archive_status(&self) -> Result<Option<ArchiveStatus>>; fn blob_committed_block_count(&self) -> Result<Option<i32>>; fn is_sealed(&self) -> Result<Option<bool>>; fn blob_sequence_number(&self) -> Result<Option<i64>>; fn blob_type(&self) -> Result<Option<BlobType>>; fn copy_completion_time(&self) -> Result<Option<OffsetDateTime>>; fn destination_snapshot(&self) -> Result<Option<String>>; fn copy_id(&self) -> Result<Option<String>>; fn copy_progress(&self) -> Result<Option<String>>; fn copy_source(&self) -> Result<Option<String>>; fn copy_status(&self) -> Result<Option<CopyStatus>>; fn copy_status_description(&self) -> Result<Option<String>>; fn creation_time(&self) -> Result<Option<OffsetDateTime>>; fn encryption_key_sha256(&self) -> Result<Option<String>>; fn encryption_scope(&self) -> Result<Option<String>>; fn expires_on(&self) -> Result<Option<OffsetDateTime>>; fn immutability_policy_mode(&self) -> Result<Option<ImmutabilityPolicyMode>>; fn immutability_policy_expires_on(&self) -> Result<Option<OffsetDateTime>>; fn is_incremental_copy(&self) -> Result<Option<bool>>; fn is_current_version(&self) -> Result<Option<bool>>; fn last_accessed(&self) -> Result<Option<OffsetDateTime>>; fn duration(&self) -> Result<Option<LeaseDuration>>; fn lease_state(&self) -> Result<Option<LeaseState>>; fn lease_status(&self) -> Result<Option<LeaseStatus>>; fn legal_hold(&self) -> Result<Option<bool>>; fn metadata(&self) -> Result<HashMap<String, String>>; fn object_replication_rules(&self) -> Result<HashMap<String, String>>; fn object_replication_policy_id(&self) -> Result<Option<String>>; fn rehydrate_priority(&self) -> Result<Option<RehydratePriority>>; fn is_server_encrypted(&self) -> Result<Option<bool>>; fn tag_count(&self) -> Result<Option<i64>>; fn version_id(&self) -> Result<Option<String>>;
}
Provides access to typed response headers for BlobClient::get_properties()

Examples

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobClientGetPropertiesResult, BlobClientGetPropertiesResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobClientGetPropertiesResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(cache_control) = response.cache_control()? {
        println!("cache-control: {:?}", cache_control);
    }
    if let Some(content_disposition) = response.content_disposition()? {
        println!("content-disposition: {:?}", content_disposition);
    }
    if let Some(content_encoding) = response.content_encoding()? {
        println!("content-encoding: {:?}", content_encoding);
    }
    Ok(())
}

Required Methods

fn cache_control(&self) -> Result<Option<String>>

fn content_disposition(&self) -> Result<Option<String>>

fn content_encoding(&self) -> Result<Option<String>>

fn content_language(&self) -> Result<Option<String>>

fn content_length(&self) -> Result<Option<u64>>

fn content_md5(&self) -> Result<Option<Vec<u8>>>

fn content_type(&self) -> Result<Option<String>>

fn etag(&self) -> Result<Option<Etag>>

fn last_modified(&self) -> Result<Option<OffsetDateTime>>

fn access_tier(&self) -> Result<Option<String>>

fn access_tier_change_time(&self) -> Result<Option<OffsetDateTime>>

fn access_tier_inferred(&self) -> Result<Option<bool>>

fn archive_status(&self) -> Result<Option<ArchiveStatus>>

fn blob_committed_block_count(&self) -> Result<Option<i32>>

fn is_sealed(&self) -> Result<Option<bool>>

fn blob_sequence_number(&self) -> Result<Option<i64>>

fn blob_type(&self) -> Result<Option<BlobType>>

fn copy_completion_time(&self) -> Result<Option<OffsetDateTime>>

fn destination_snapshot(&self) -> Result<Option<String>>

fn copy_id(&self) -> Result<Option<String>>

fn copy_progress(&self) -> Result<Option<String>>

fn copy_source(&self) -> Result<Option<String>>

fn copy_status(&self) -> Result<Option<CopyStatus>>

fn copy_status_description(&self) -> Result<Option<String>>

fn creation_time(&self) -> Result<Option<OffsetDateTime>>

fn encryption_key_sha256(&self) -> Result<Option<String>>

fn encryption_scope(&self) -> Result<Option<String>>

fn expires_on(&self) -> Result<Option<OffsetDateTime>>

fn immutability_policy_mode(&self) -> Result<Option<ImmutabilityPolicyMode>>

fn immutability_policy_expires_on(&self) -> Result<Option<OffsetDateTime>>

fn is_incremental_copy(&self) -> Result<Option<bool>>

fn is_current_version(&self) -> Result<Option<bool>>

fn last_accessed(&self) -> Result<Option<OffsetDateTime>>

fn duration(&self) -> Result<Option<LeaseDuration>>

fn lease_state(&self) -> Result<Option<LeaseState>>

fn lease_status(&self) -> Result<Option<LeaseStatus>>

fn legal_hold(&self) -> Result<Option<bool>>

fn metadata(&self) -> Result<HashMap<String, String>>

fn object_replication_rules(&self) -> Result<HashMap<String, String>>

fn object_replication_policy_id(&self) -> Result<Option<String>>

fn rehydrate_priority(&self) -> Result<Option<RehydratePriority>>

fn is_server_encrypted(&self) -> Result<Option<bool>>

fn tag_count(&self) -> Result<Option<i64>>

fn version_id(&self) -> Result<Option<String>>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BlobClientGetPropertiesResultHeaders for Response<BlobClientGetPropertiesResult, NoFormat>

Source

fn cache_control(&self) -> Result<Option<String>>

The Cache-Control of the blob.

Source

fn content_disposition(&self) -> Result<Option<String>>

The Content-Disposition of the blob.

Source

fn content_encoding(&self) -> Result<Option<String>>

The Content-Encoding of the blob.

Source

fn content_language(&self) -> Result<Option<String>>

The Content-Language of the blob.

Source

fn content_length(&self) -> Result<Option<u64>>

The number of bytes present in the response body.

Source

fn content_md5(&self) -> Result<Option<Vec<u8>>>

The blob content MD5 hash. Only returned if the full blob is read.

Source

fn content_type(&self) -> Result<Option<String>>

Content-type.

Source

fn etag(&self) -> Result<Option<Etag>>

An opaque identifier for the current state of the resource.

Source

fn last_modified(&self) -> Result<Option<OffsetDateTime>>

The date-time that the resource was last modified.

Source

fn access_tier(&self) -> Result<Option<String>>

The access tier of the blob.

Source

fn access_tier_change_time(&self) -> Result<Option<OffsetDateTime>>

The time the tier was changed on the blob. This is only returned if the tier on the blob was ever set.

Source

fn access_tier_inferred(&self) -> Result<Option<bool>>

Included if the access tier is inferred.

Source

fn archive_status(&self) -> Result<Option<ArchiveStatus>>

Included if the blob rehydrate operation is pending. Indicates the destination tier.

Source

fn blob_committed_block_count(&self) -> Result<Option<i32>>

The number of committed blocks present in the blob.

Source

fn is_sealed(&self) -> Result<Option<bool>>

Whether the blob is sealed.

Source

fn blob_sequence_number(&self) -> Result<Option<i64>>

The current sequence number for a page blob.

Source

fn blob_type(&self) -> Result<Option<BlobType>>

The type of the blob.

Source

fn copy_completion_time(&self) -> Result<Option<OffsetDateTime>>

If this blob was the destination of a copy, specifies the completion time of the last attempted copy operation.

Source

fn destination_snapshot(&self) -> Result<Option<String>>

Included if the blob is incremental copy blob or incremental copy snapshot, if x-ms-copy-status is success.

Source

fn copy_id(&self) -> Result<Option<String>>

Identifier for this copy operation.

Source

fn copy_progress(&self) -> Result<Option<String>>

If this blob was the destination of a copy, specifies the number of bytes copied and the total bytes in the source.

Source

fn copy_source(&self) -> Result<Option<String>>

If this blob was the destination of a copy, specifies the source URL.

Source

fn copy_status(&self) -> Result<Option<CopyStatus>>

Status of the copy operation.

Source

fn copy_status_description(&self) -> Result<Option<String>>

If this blob was the destination of a copy, specifies the cause of the copy operation failure.

Source

fn creation_time(&self) -> Result<Option<OffsetDateTime>>

The date-time the blob was created.

Source

fn encryption_key_sha256(&self) -> Result<Option<String>>

The SHA-256 hash of the provided encryption key.

Source

fn encryption_scope(&self) -> Result<Option<String>>

Specifies the encryption scope used to encrypt the data.

Source

fn expires_on(&self) -> Result<Option<OffsetDateTime>>

The date-time this blob will expire.

Source

fn immutability_policy_mode(&self) -> Result<Option<ImmutabilityPolicyMode>>

Indicates the immutability policy mode of the blob.

Source

fn immutability_policy_expires_on(&self) -> Result<Option<OffsetDateTime>>

The date-time that indicates the time at which the blob immutability policy will expire.

Source

fn is_incremental_copy(&self) -> Result<Option<bool>>

Included if the blob is incremental copy blob.

Source

fn is_current_version(&self) -> Result<Option<bool>>

Indicates whether this is the current version of the blob.

Source

fn last_accessed(&self) -> Result<Option<OffsetDateTime>>

The date-time value that indicates the time at which the blob was last read or written.

Source

fn duration(&self) -> Result<Option<LeaseDuration>>

Specifies the duration of the lease.

Source

fn lease_state(&self) -> Result<Option<LeaseState>>

The lease state of the blob.

Source

fn lease_status(&self) -> Result<Option<LeaseStatus>>

The lease status of the blob.

Source

fn legal_hold(&self) -> Result<Option<bool>>

Indicates whether the blob has a legal hold.

Source

fn metadata(&self) -> Result<HashMap<String, String>>

The metadata headers.

Source

fn object_replication_rules(&self) -> Result<HashMap<String, String>>

The object replication status headers.

Source

fn object_replication_policy_id(&self) -> Result<Option<String>>

The object replication policy ID.

Source

fn rehydrate_priority(&self) -> Result<Option<RehydratePriority>>

The priority of the rehydration operation.

Source

fn is_server_encrypted(&self) -> Result<Option<bool>>

Indicates whether the contents of the request are successfully encrypted.

Source

fn tag_count(&self) -> Result<Option<i64>>

The number of tags associated with the blob.

Source

fn version_id(&self) -> Result<Option<String>>

The version ID of the blob.

Implementors