BlobContainerClientGetPropertiesResultHeaders

Trait BlobContainerClientGetPropertiesResultHeaders 

pub trait BlobContainerClientGetPropertiesResultHeaders: Sealed {
    // Required methods
    fn etag(&self) -> Result<Option<Etag>>;
    fn last_modified(&self) -> Result<Option<OffsetDateTime>>;
    fn access(&self) -> Result<Option<PublicAccessType>>;
    fn default_encryption_scope(&self) -> Result<Option<String>>;
    fn prevent_encryption_scope_override(&self) -> Result<Option<bool>>;
    fn has_immutability_policy(&self) -> Result<Option<bool>>;
    fn has_legal_hold(&self) -> Result<Option<bool>>;
    fn is_immutable_storage_with_versioning_enabled(
        &self,
    ) -> Result<Option<bool>>;
    fn duration(&self) -> Result<Option<LeaseDuration>>;
    fn lease_state(&self) -> Result<Option<LeaseState>>;
    fn lease_status(&self) -> Result<Option<LeaseStatus>>;
    fn metadata(&self) -> Result<HashMap<String, String>>;
}
Provides access to typed response headers for BlobContainerClient::get_properties()

Examples

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobContainerClientGetPropertiesResult, BlobContainerClientGetPropertiesResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobContainerClientGetPropertiesResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(access) = response.access()? {
        println!("x-ms-blob-public-access: {:?}", access);
    }
    Ok(())
}

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BlobContainerClientGetPropertiesResultHeaders for Response<BlobContainerClientGetPropertiesResult, NoFormat>

Source

fn etag(&self) -> Result<Option<Etag>>

An opaque identifier for the current state of the resource.

Source

fn last_modified(&self) -> Result<Option<OffsetDateTime>>

The date-time that the resource was last modified.

Source

fn access(&self) -> Result<Option<PublicAccessType>>

The public access setting for the container.

Source

fn default_encryption_scope(&self) -> Result<Option<String>>

The default encryption scope for the container.

Source

fn prevent_encryption_scope_override(&self) -> Result<Option<bool>>

Whether to prevent encryption scope override.

Source

fn has_immutability_policy(&self) -> Result<Option<bool>>

Indicates whether the container has an immutability policy set on it.

Indicates whether the container has a legal hold.

Source

fn is_immutable_storage_with_versioning_enabled(&self) -> Result<Option<bool>>

Indicates whether version level WORM (Write Once, Read Many) is enabled on a container.

Source

fn duration(&self) -> Result<Option<LeaseDuration>>

Specifies the duration of the lease.

Source

fn lease_state(&self) -> Result<Option<LeaseState>>

The lease state of the blob.

Source

fn lease_status(&self) -> Result<Option<LeaseStatus>>

The lease status of the blob.

Source

fn metadata(&self) -> Result<HashMap<String, String>>

The metadata headers.

Implementors