BlockBlobClientStageBlockFromUrlResultHeaders

Trait BlockBlobClientStageBlockFromUrlResultHeaders 

pub trait BlockBlobClientStageBlockFromUrlResultHeaders: Sealed {
    // Required methods
    fn content_md5(&self) -> Result<Option<Vec<u8>>>;
    fn content_crc64(&self) -> Result<Option<Vec<u8>>>;
    fn encryption_key_sha256(&self) -> Result<Option<String>>;
    fn encryption_scope(&self) -> Result<Option<String>>;
    fn is_server_encrypted(&self) -> Result<Option<bool>>;
}
Provides access to typed response headers for BlockBlobClient::stage_block_from_url()

Examples

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlockBlobClientStageBlockFromUrlResult, BlockBlobClientStageBlockFromUrlResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlockBlobClientStageBlockFromUrlResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(content_md5) = response.content_md5()? {
        println!("content-md5: {:?}", content_md5);
    }
    if let Some(content_crc64) = response.content_crc64()? {
        println!("x-ms-content-crc64: {:?}", content_crc64);
    }
    if let Some(encryption_key_sha256) = response.encryption_key_sha256()? {
        println!("x-ms-encryption-key-sha256: {:?}", encryption_key_sha256);
    }
    Ok(())
}

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BlockBlobClientStageBlockFromUrlResultHeaders for Response<BlockBlobClientStageBlockFromUrlResult, NoFormat>

Source

fn content_md5(&self) -> Result<Option<Vec<u8>>>

The blob content MD5 hash. Only returned if the full blob is read.

Source

fn content_crc64(&self) -> Result<Option<Vec<u8>>>

The CRC64 hash of the content.

Source

fn encryption_key_sha256(&self) -> Result<Option<String>>

The SHA-256 hash of the provided encryption key.

Source

fn encryption_scope(&self) -> Result<Option<String>>

Specifies the encryption scope used to encrypt the data.

Source

fn is_server_encrypted(&self) -> Result<Option<bool>>

Indicates whether the contents of the request are successfully encrypted.

Implementors