BlockBlobClientUploadBlobFromUrlResultHeaders

Trait BlockBlobClientUploadBlobFromUrlResultHeaders 

pub trait BlockBlobClientUploadBlobFromUrlResultHeaders: Sealed {
    // Required methods
    fn content_md5(&self) -> Result<Option<Vec<u8>>>;
    fn etag(&self) -> Result<Option<Etag>>;
    fn last_modified(&self) -> Result<Option<OffsetDateTime>>;
    fn encryption_key_sha256(&self) -> Result<Option<String>>;
    fn encryption_scope(&self) -> Result<Option<String>>;
    fn is_server_encrypted(&self) -> Result<Option<bool>>;
    fn version_id(&self) -> Result<Option<String>>;
}
Provides access to typed response headers for BlockBlobClient::upload_blob_from_url()

Examples

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlockBlobClientUploadBlobFromUrlResult, BlockBlobClientUploadBlobFromUrlResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlockBlobClientUploadBlobFromUrlResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(content_md5) = response.content_md5()? {
        println!("content-md5: {:?}", content_md5);
    }
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    Ok(())
}

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BlockBlobClientUploadBlobFromUrlResultHeaders for Response<BlockBlobClientUploadBlobFromUrlResult, NoFormat>

Source

fn content_md5(&self) -> Result<Option<Vec<u8>>>

The blob content MD5 hash. Only returned if the full blob is read.

Source

fn etag(&self) -> Result<Option<Etag>>

An opaque identifier for the current state of the resource.

Source

fn last_modified(&self) -> Result<Option<OffsetDateTime>>

The date-time that the resource was last modified.

Source

fn encryption_key_sha256(&self) -> Result<Option<String>>

The SHA-256 hash of the provided encryption key.

Source

fn encryption_scope(&self) -> Result<Option<String>>

Specifies the encryption scope used to encrypt the data.

Source

fn is_server_encrypted(&self) -> Result<Option<bool>>

Indicates whether the contents of the request are successfully encrypted.

Source

fn version_id(&self) -> Result<Option<String>>

The version ID of the blob.

Implementors