pub struct BlobClientDownloadOptions<'a> {Show 18 fields
pub encryption_algorithm: Option<EncryptionAlgorithmType>,
pub encryption_key: Option<String>,
pub encryption_key_sha256: Option<String>,
pub if_match: Option<Etag>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_none_match: Option<Etag>,
pub if_tags: Option<String>,
pub if_unmodified_since: Option<OffsetDateTime>,
pub lease_id: Option<String>,
pub method_options: ClientMethodOptions<'a>,
pub parallel: Option<NonZero<usize>>,
pub partition_size: Option<NonZero<usize>>,
pub range: Option<HttpRange>,
pub range_get_content_crc64: Option<bool>,
pub range_get_content_md5: Option<bool>,
pub snapshot: Option<String>,
pub timeout: Option<i32>,
pub version_id: Option<String>,
}Expand description
Options to be passed to BlobClient::download()
Fields
encryption_algorithm: Option<EncryptionAlgorithmType>The algorithm used to produce the encryption key hash. Must be provided if the encryption key is provided.
encryption_key: Option<String>Specifies the encryption key to use to encrypt the data provided in the request.
encryption_key_sha256: Option<String>The SHA-256 hash of the provided encryption key. Must be provided if the encryption key is provided.
if_match: Option<Etag>Specify this value to operate only on a blob with a matching Etag value.
if_modified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has been modified since the specified date-time.
if_none_match: Option<Etag>Specify this value to operate only on a blob with a non-matching Etag value.
Specifies a SQL-like where clause on blob tags to operate only on a blob with matching tags.
if_unmodified_since: Option<OffsetDateTime>Specify this value to operate only on a blob if it has not been modified since the specified date-time.
lease_id: Option<String>If specified, the operation only succeeds if the resource’s lease is active and matches this ID.
method_options: ClientMethodOptions<'a>Allows customization of the method call.
parallel: Option<NonZero<usize>>Optional. Number of concurrent network transfers to maintain for this operation. A default value will be chosen if none is provided.
partition_size: Option<NonZero<usize>>Optional. Size to partition data into. A default value will be chosen if none is provided.
range: Option<HttpRange>Optional range of the blob to download.
Accepts an HttpRange value. You can convert from standard Rust range types
using .into(), for example (0..100u64).into() or (100u64..).into().
When set to None, the entire blob will be downloaded.
range_get_content_crc64: Option<bool>When set to true and the request includes a Range header, the service returns the CRC64 hash for the range, as long as the range is less than or equal to 4 MiB in size.
range_get_content_md5: Option<bool>When set to true and specified together with the Range header, the service returns the MD5 hash for the range, as long
as the range is less than or equal to 4 MiB in size.
snapshot: Option<String>Specifies the snapshot of the blob.
timeout: Option<i32>The timeout parameter is expressed in seconds. For more information, see Setting Timeouts for Blob Service Operations.
version_id: Option<String>Specifies the version ID of the blob.