#[non_exhaustive]pub struct GeoReplication {
pub last_sync_time: Option<OffsetDateTime>,
pub status: Option<GeoReplicationStatusType>,
}Expand description
Geo-replication information for the secondary storage service.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.last_sync_time: Option<OffsetDateTime>A date-time value that indicates where all primary writes preceding this value are guaranteed to be available for read operations at the secondary. Primary writes after this point in time may or may not be available for reads.
status: Option<GeoReplicationStatusType>The status of the secondary location.