#[non_exhaustive]pub struct ListContainersResponse {
pub container_items: Vec<ContainerItem>,
pub marker: Option<String>,
pub max_results: Option<i32>,
pub next_marker: Option<String>,
pub prefix: Option<String>,
pub service_endpoint: Option<String>,
}Expand description
The result of the List Containers API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.container_items: Vec<ContainerItem>The list of containers.
marker: Option<String>An opaque string value that identifies the portion of the result set returned with this operation.
max_results: Option<i32>The maximum number of containers to be returned with this operation.
next_marker: Option<String>An opaque string value that identifies the portion of the result set to be returned with the next operation. Use this value in the next request to continue the listing operation.
prefix: Option<String>The prefix of the containers.
service_endpoint: Option<String>The service endpoint.