#[non_exhaustive]pub struct PageList {
pub clear_ranges: Option<Vec<ClearRange>>,
pub next_marker: Option<String>,
pub page_ranges: Vec<PageRange>,
}Expand description
The result of the Get Pages API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.clear_ranges: Option<Vec<ClearRange>>The clear ranges.
next_marker: Option<String>An opaque string value that identifies the portion of the result set to be returned with the next operation. Use this value in the next request to continue the listing operation.
page_ranges: Vec<PageRange>The page ranges.