pub trait AppendBlobClientAppendBlockResultHeaders: Sealed {
// Required methods
fn content_md5(&self) -> Result<Option<Vec<u8>>>;
fn etag(&self) -> Result<Option<Etag>>;
fn last_modified(&self) -> Result<Option<OffsetDateTime>>;
fn blob_append_offset(&self) -> Result<Option<String>>;
fn blob_committed_block_count(&self) -> Result<Option<i32>>;
fn content_crc64(&self) -> Result<Option<Vec<u8>>>;
fn encryption_key_sha256(&self) -> Result<Option<String>>;
fn encryption_scope(&self) -> Result<Option<String>>;
fn is_server_encrypted(&self) -> Result<Option<bool>>;
}Expand description
Provides access to typed response headers for AppendBlobClient::append_block()
Examples
use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{AppendBlobClientAppendBlockResult, AppendBlobClientAppendBlockResultHeaders};
async fn example() -> Result<()> {
let response: Response<AppendBlobClientAppendBlockResult, NoFormat> = unimplemented!();
// Access response headers
if let Some(content_md5) = response.content_md5()? {
println!("content-md5: {:?}", content_md5);
}
if let Some(etag) = response.etag()? {
println!("etag: {:?}", etag);
}
if let Some(last_modified) = response.last_modified()? {
println!("last-modified: {:?}", last_modified);
}
Ok(())
}Required Methods
fn content_md5(&self) -> Result<Option<Vec<u8>>>
fn etag(&self) -> Result<Option<Etag>>
fn last_modified(&self) -> Result<Option<OffsetDateTime>>
fn blob_append_offset(&self) -> Result<Option<String>>
fn blob_committed_block_count(&self) -> Result<Option<i32>>
fn content_crc64(&self) -> Result<Option<Vec<u8>>>
fn encryption_key_sha256(&self) -> Result<Option<String>>
fn encryption_scope(&self) -> Result<Option<String>>
fn is_server_encrypted(&self) -> Result<Option<bool>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl AppendBlobClientAppendBlockResultHeaders for Response<AppendBlobClientAppendBlockResult, NoFormat>
impl AppendBlobClientAppendBlockResultHeaders for Response<AppendBlobClientAppendBlockResult, NoFormat>
Sourcefn content_md5(&self) -> Result<Option<Vec<u8>>>
fn content_md5(&self) -> Result<Option<Vec<u8>>>
The blob content MD5 hash. Only returned if the full blob is read.
Sourcefn etag(&self) -> Result<Option<Etag>>
fn etag(&self) -> Result<Option<Etag>>
An opaque identifier for the current state of the resource.
Sourcefn last_modified(&self) -> Result<Option<OffsetDateTime>>
fn last_modified(&self) -> Result<Option<OffsetDateTime>>
The date-time that the resource was last modified.
Sourcefn blob_append_offset(&self) -> Result<Option<String>>
fn blob_append_offset(&self) -> Result<Option<String>>
The offset at which the block was committed, in bytes.
Sourcefn blob_committed_block_count(&self) -> Result<Option<i32>>
fn blob_committed_block_count(&self) -> Result<Option<i32>>
The number of committed blocks present in the blob.
Sourcefn encryption_key_sha256(&self) -> Result<Option<String>>
fn encryption_key_sha256(&self) -> Result<Option<String>>
The SHA-256 hash of the provided encryption key.