pub trait BlobClientCreateSnapshotResultHeaders: Sealed {
// Required methods
fn etag(&self) -> Result<Option<Etag>>;
fn last_modified(&self) -> Result<Option<OffsetDateTime>>;
fn is_server_encrypted(&self) -> Result<Option<bool>>;
fn snapshot(&self) -> Result<Option<String>>;
fn version_id(&self) -> Result<Option<String>>;
}Expand description
Provides access to typed response headers for BlobClient::create_snapshot()
Examples
use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobClientCreateSnapshotResult, BlobClientCreateSnapshotResultHeaders};
async fn example() -> Result<()> {
let response: Response<BlobClientCreateSnapshotResult, NoFormat> = unimplemented!();
// Access response headers
if let Some(etag) = response.etag()? {
println!("etag: {:?}", etag);
}
if let Some(last_modified) = response.last_modified()? {
println!("last-modified: {:?}", last_modified);
}
if let Some(is_server_encrypted) = response.is_server_encrypted()? {
println!("x-ms-request-server-encrypted: {:?}", is_server_encrypted);
}
Ok(())
}Required Methods
fn etag(&self) -> Result<Option<Etag>>
fn last_modified(&self) -> Result<Option<OffsetDateTime>>
fn is_server_encrypted(&self) -> Result<Option<bool>>
fn snapshot(&self) -> Result<Option<String>>
fn version_id(&self) -> Result<Option<String>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl BlobClientCreateSnapshotResultHeaders for Response<BlobClientCreateSnapshotResult, NoFormat>
impl BlobClientCreateSnapshotResultHeaders for Response<BlobClientCreateSnapshotResult, NoFormat>
Sourcefn etag(&self) -> Result<Option<Etag>>
fn etag(&self) -> Result<Option<Etag>>
An opaque identifier for the current state of the resource.
Sourcefn last_modified(&self) -> Result<Option<OffsetDateTime>>
fn last_modified(&self) -> Result<Option<OffsetDateTime>>
The date-time that the resource was last modified.
Sourcefn is_server_encrypted(&self) -> Result<Option<bool>>
fn is_server_encrypted(&self) -> Result<Option<bool>>
Indicates whether the contents of the request are successfully encrypted.